@@ -319,6 +319,11 @@ anjuta_plugin_class_init (AnjutaPluginClass *class)
 	class->activate = NULL;
 	class->deactivate = NULL;
 
+	/**
+	 * AnjutaPlugin:shell:
+	 *
+	 * The #AnjutaShell object associated with this plugin
+	 */
 	g_object_class_install_property
 		(object_class,
 		 PROP_SHELL,
@@ -405,8 +410,8 @@ value_removed_cb (AnjutaShell *shell,
  * anjuta_plugin_add_watch:
  * @plugin: a #AnjutaPlugin derived class object.
  * @name: Name of the value to watch.
- * @added: Callback to call when the value is added.
- * @removed: Callback to call when the value is removed.
+ * @added: (closure user_data) (scope call): Callback to call when the value is added.
+ * @removed: (closure user_data) (scope call): Callback to call when the value is removed.
  * @user_data: User data to pass to callbacks.
  * 
  * Adds a watch for @name value. When the value is added in shell, the @added
@@ -585,3 +590,16 @@ anjuta_plugin_is_active (AnjutaPlugin *plugin)
 {
 	return plugin->priv->activated;
 }
+
+/**
+ * anjuta_plugin_get_shell:
+ * @plugin: a #AnjutaPlugin
+ * 
+ * Returns: The #AnjutaShell object associated with this plugin
+ */
+AnjutaShell *
+anjuta_plugin_get_shell (AnjutaPlugin* plugin)
+{
+	return plugin->shell;
+}
+
