@@ -24,12 +24,16 @@
 
 #include "am-project.h"
 #include "command-queue.h"
+#include <libanjuta/interfaces/ianjuta-language.h>
 
 G_BEGIN_DECLS
 
 typedef enum {
 	AM_PROPERTY_IN_CONFIGURE = 1 << 0,
-	AM_PROPERTY_IN_MAKEFILE = 1 << 1
+	AM_PROPERTY_IN_MAKEFILE = 1 << 1,
+	AM_PROPERTY_DIRECTORY = 1 << 2,						/* Directory property (having dir suffix) */
+	AM_PROPERTY_DISABLE_FOLLOWING = 1 << 3,		/* Disable following property if true */
+	AM_PROPERTY_COMPILATION_FLAG = 1 << 4			/* Target compilation flags, need a specific object */
 } AmpPropertyFlag;
 
 
@@ -40,6 +44,7 @@ struct _AmpProperty {
 	const gchar *suffix;
 	AmpPropertyFlag flags;
 	AnjutaToken *token;
+	AmpProperty *link;			/* Link to a boolean property disabling this one */
 };
 
 struct _AmpProject {
@@ -73,6 +78,9 @@ struct _AmpProject {
 
 	/* Command queue */
 	PmCommandQueue *queue;
+
+	/* Language Manager */
+	IAnjutaLanguage *lang_manager;
 };
 
 typedef struct _AmpNodeInfo AmpNodeInfo;
