@@ -453,6 +453,7 @@ amp_project_clear (AmpProject *project)
 	if (project->configure_file != NULL) anjuta_token_file_free (project->configure_file);
 	project->configure_file = NULL;
 	if (project->configure_token) anjuta_token_free (project->configure_token);
+	project->configure_token = NULL;
 }
 
 static void
@@ -520,7 +521,6 @@ AnjutaToken*
 amp_project_get_configure_token (AmpProject *project)
 {
 	return project->configure_token;
-
 }
 
 AnjutaToken *
@@ -787,13 +787,13 @@ amp_project_load_config (AmpProject *project, AnjutaToken *arg_list)
 		/* File list */
 		scanner = amp_ac_scanner_new (project);
 		
-		arg = anjuta_token_first_item (arg_list);
+		arg = anjuta_token_first_word (arg_list);
 		list = amp_ac_scanner_parse_token (scanner, arg, AC_SPACE_LIST_STATE, NULL);
 		anjuta_token_free_children (arg);
 		list = anjuta_token_delete_parent (list);
 		anjuta_token_prepend_items (arg, list);
 		amp_ac_scanner_free (scanner);
-		
+
 		for (item = anjuta_token_first_word (arg); item != NULL; item = anjuta_token_next_word (item))
 		{
 			gchar *value;
@@ -1030,6 +1030,7 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *group, AnjutaToken
 						{
 							/* Create object node */
 							gchar *object_name;
+							gchar *basename;
 							gchar *ext;
 							GFile *obj_file;
 							AnjutaProjectNode *object;
@@ -1037,7 +1038,9 @@ project_load_sources (AmpProject *project, AnjutaProjectNode *group, AnjutaToken
 							ext = strrchr (value, '.');
 							if ((ext != NULL) && (ext != value)) *ext = '\0';
 							object_name = g_strconcat (value, obj_ext, NULL);
-							obj_file = g_file_get_child (group_file, object_name);
+							basename = g_path_get_basename (object_name);
+							obj_file = g_file_get_child (group_file, basename);
+							g_free (basename);
 							g_free (object_name);
 							object = amp_node_new_valid (group, ANJUTA_PROJECT_OBJECT | ANJUTA_PROJECT_PROJECT, obj_file, NULL, NULL); 
 							g_object_unref (obj_file);
@@ -1641,6 +1644,7 @@ amp_project_load_root (AmpProject *project, GError **error)
 	scanner = amp_ac_scanner_new (project);
 	project->configure_token = amp_ac_scanner_parse_token (scanner, arg, 0, &err);
 	amp_ac_scanner_free (scanner);
+	
 	if (project->configure_token == NULL)
 	{
 		g_set_error (error, IANJUTA_PROJECT_ERROR, 
@@ -2244,7 +2248,7 @@ static gboolean
 iproject_load_node (IAnjutaProject *obj, AnjutaProjectNode *node, GError **error)
 {
 	PmJob *load_job;
-	
+
 	if (node == NULL) node = ANJUTA_PROJECT_NODE (obj);
 	if (AMP_PROJECT (obj)->queue == NULL) AMP_PROJECT (obj)->queue = pm_command_queue_new ();
 
