@@ -41,18 +41,20 @@ void amp_am_scanner_free (AmpAmScanner *scanner);
 
 AnjutaToken *amp_am_scanner_parse_token (AmpAmScanner *scanner, AnjutaToken *root, AnjutaToken *content, GFile *filename, GError **error);
 
-void amp_am_scanner_set_am_variable (AmpAmScanner *scanner, AnjutaTokenType variable, AnjutaToken *name, AnjutaToken *list);
+void amp_am_scanner_set_am_variable (AmpAmScanner *scanner, AnjutaToken *variable);
 void amp_am_scanner_include (AmpAmScanner *scanner, AnjutaToken *name);
 void amp_am_scanner_update_variable (AmpAmScanner *scanner, AnjutaToken *variable);
 
-void amp_project_set_am_variable (AmpProject* project, AmpGroupNode* group, AnjutaTokenType variable, AnjutaToken *name, AnjutaToken *list, GHashTable *orphan_properties);
+void amp_project_set_am_variable (AmpProject* project, AmpGroupNode* group, AnjutaToken *variable, GHashTable *orphan_properties);
 
 
 void amp_am_yyerror (YYLTYPE *loc, AmpAmScanner *scanner, char const *s);
 
 typedef enum
 {
-	AM_TOKEN_SUBDIRS = ANJUTA_TOKEN_USER,
+	/* Order is important as the backend will try to follow it */
+	AM_TOKEN_FIRST_ORDERED_MACRO = ANJUTA_TOKEN_USER,
+	AM_TOKEN_SUBDIRS,
 	AM_TOKEN_DIST_SUBDIRS,
 	AM_TOKEN__DATA,
 	AM_TOKEN__HEADERS,
@@ -63,7 +65,6 @@ typedef enum
 	AM_TOKEN__PROGRAMS,
 	AM_TOKEN__PYTHON,
 	AM_TOKEN__SCRIPTS,
-	AM_TOKEN__SOURCES,
 	AM_TOKEN__TEXINFOS,
 	AM_TOKEN__JAVA,
 	AM_TOKEN_DIR,
@@ -77,19 +78,26 @@ typedef enum
 	AM_TOKEN__OBJCFLAGS,
 	AM_TOKEN__LFLAGS,
 	AM_TOKEN__YFLAGS,
-	AM_TOKEN_TARGET_LDFLAGS,
+	
+	AM_TOKEN_FIRST_ORDERED_TARGET_MACRO,
+	AM_TOKEN__SOURCES,
 	AM_TOKEN_TARGET_CPPFLAGS,
 	AM_TOKEN_TARGET_CFLAGS,
 	AM_TOKEN_TARGET_CXXFLAGS,
-	AM_TOKEN_TARGET_JAVACFLAGS,
-	AM_TOKEN_TARGET_VALAFLAGS,
-	AM_TOKEN_TARGET_FCFLAGS,
 	AM_TOKEN_TARGET_OBJCFLAGS,
+	AM_TOKEN_TARGET_VALAFLAGS,
+	AM_TOKEN_TARGET_JAVACFLAGS,
 	AM_TOKEN_TARGET_LFLAGS,
 	AM_TOKEN_TARGET_YFLAGS,
-	AM_TOKEN_TARGET_DEPENDENCIES,
+	AM_TOKEN_TARGET_FCFLAGS,
+	AM_TOKEN_TARGET_LDFLAGS,
 	AM_TOKEN_TARGET_LIBADD,
-	AM_TOKEN_TARGET_LDADD
+	AM_TOKEN_TARGET_LDADD,
+	AM_TOKEN_TARGET_DEPENDENCIES,
+	AM_TOKEN_LAST_ORDERED_TARGET_MACRO,
+
+	AM_TOKEN_LAST_ORDERED_MACRO,
+		
 } AmTokenType;
 
 G_END_DECLS
