@@ -62,14 +62,17 @@ typedef enum _AmpTargetNodeFlag
 void amp_target_node_register (GTypeModule *module);
 
 void amp_target_node_add_token (AmpTargetNode *target, AmTokenType type, AnjutaToken *token);
+void amp_target_node_remove_token (AmpTargetNode *target, AnjutaToken *token);
 GList * amp_target_node_get_token (AmpTargetNode *target, AmTokenType type);
 GList * amp_target_node_get_all_token (AmpTargetNode *target);
 void amp_target_node_set_type (AmpTargetNode *target, AmTokenType type);
 AnjutaTokenType amp_target_node_get_first_token_type (AmpTargetNode *target);
 AnjutaTokenType amp_target_node_get_next_token_type (AmpTargetNode *target, AnjutaTokenType type);
-AmpTargetNode* amp_target_node_new (const gchar *name, AnjutaProjectNodeType type, const gchar *install, gint flags, GError **error);
+AmpTargetNode* amp_target_node_new (const gchar *name, AnjutaProjectNodeType type, const gchar *install, gint flags);
+AmpTargetNode* amp_target_node_new_valid (const gchar *name, AnjutaProjectNodeType type, const gchar *install, gint flags, GError **error);
 void amp_target_node_free (AmpTargetNode *node);
 void amp_target_node_update_node (AmpTargetNode *node, AmpTargetNode *new_node);
+void amp_target_changed (AmpTargetNode *node);
 
 G_END_DECLS
 
