@@ -45,6 +45,7 @@ typedef enum {
 	NPW_DIRECTORY_PROPERTY,
 	NPW_FILE_PROPERTY,
 	NPW_ICON_PROPERTY,
+	NPW_PACKAGE_PROPERTY,
 	NPW_LAST_PROPERTY
 } NPWPropertyType;
 
@@ -71,6 +72,13 @@ typedef enum {
 	NPW_TRUE = 1
 } NPWPropertyBooleanValue;
 
+typedef enum
+{
+	NPW_MIN_MARK = 0,
+	NPW_MAX_MARK = 1,
+	NPW_STEP_MARK = 2
+} NPWPropertyRangeMark;
+
 NPWProperty* npw_property_new (void);
 void npw_property_free (NPWProperty* prop);
 
@@ -99,6 +107,8 @@ GtkWidget* npw_property_get_widget (const NPWProperty* prop);
 
 void npw_property_set_default (NPWProperty* prop, const gchar* value);
 
+gboolean npw_property_set_range (NPWProperty* prop, NPWPropertyRangeMark mark, const gchar* value);
+
 gboolean npw_property_update_value_from_widget (NPWProperty* prop);
 gboolean npw_property_save_value_from_widget (NPWProperty* prop);
 gboolean npw_property_remove_value (NPWProperty* prop);
